# -*- coding: utf-8 -*-

ABBREVIATIONS = ["dr", "jr", "mr", "mrs", "ms", "msgr", "prof", "sr", "st"]

SUB_PAIRS = [("M.", "Monsieur")]

ALL_PUNC = "?!？！.,¡()[]¿…‥،;:—。，、：\n"

TONE_MARKS = "?!？！"

PERIOD_COMMA = ".,"

COLON = ":"
